@@ -6,11 +6,11 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-use Latin1;
+use Latin2;
 
-$| = 1;
-print "1..1\n";
-print "ok - 1\n";
+BEGIN { $| = 1; print "1..1\n"; }
+
+print "ok 1\n";
 
 ######################### End of black magic.
 
